==> haskell-hourglass-0.2.9-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-hourglass/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hourglass
version: 0.2.9
id: hourglass-0.2.9-d44f07201da9fd2656b62ae800dd5aa9
key: hourg_8MOIDfr6DODKJWnjukfaUl
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: https://github.com/vincenthz/hs-hourglass
synopsis: simple performant time related library
description:
    Simple time library focusing on simple but powerful and performant API
    .
    The backbone of the library are the Timeable and Time type classes.
    .
    Each Timeable instances can be converted to type that has a Time instances,
    and thus are different representations of current time.
category: Time
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.Hourglass Data.Hourglass.Types Data.Hourglass.Epoch
    Data.Hourglass.Compat System.Hourglass
hidden-modules: Data.Hourglass.Time Data.Hourglass.Format
                Data.Hourglass.Diff Data.Hourglass.Local Data.Hourglass.Calendar
                Data.Hourglass.Zone Data.Hourglass.Internal Data.Hourglass.Utils
                Data.Hourglass.Internal.Unix
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/hourglass-0.2.9
library-dirs: /usr/lib/ghc-7.10.3/site-local/hourglass-0.2.9
data-dir: /usr/share/arm-linux-ghc-7.10.3/hourglass-0.2.9
hs-libraries: HShourglass-0.2.9-8MOIDfr6DODKJWnjukfaUl
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
haddock-interfaces: /usr/share/doc/haskell-hourglass/html/hourglass.haddock
haddock-html: /usr/share/doc/haskell-hourglass/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hourglass-0.2.10-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-hourglass/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hourglass
version: 0.2.10
id: hourglass-0.2.10-b11bcf654d7049575fb45d24076b832b
key: hourg_LCfvpegcEVDEeuH0foNCGl
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: https://github.com/vincenthz/hs-hourglass
synopsis: simple performant time related library
description:
    Simple time library focusing on simple but powerful and performant API
    .
    The backbone of the library are the Timeable and Time type classes.
    .
    Each Timeable instances can be converted to type that has a Time instances,
    and thus are different representations of current time.
category: Time
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Time.Types Time.System Time.Compat Data.Hourglass
    Data.Hourglass.Types Data.Hourglass.Epoch Data.Hourglass.Compat
    System.Hourglass
hidden-modules: Data.Hourglass.Time Data.Hourglass.Format
                Data.Hourglass.Diff Data.Hourglass.Local Data.Hourglass.Calendar
                Data.Hourglass.Zone Data.Hourglass.Internal Data.Hourglass.Utils
                Data.Hourglass.Internal.Unix
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/hourglass-0.2.10
library-dirs: /usr/lib/ghc-7.10.3/site-local/hourglass-0.2.10
data-dir: /usr/share/arm-linux-ghc-7.10.3/hourglass-0.2.10
hs-libraries: HShourglass-0.2.10-LCfvpegcEVDEeuH0foNCGl
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
haddock-interfaces: /usr/share/doc/haskell-hourglass/html/hourglass.haddock
haddock-html: /usr/share/doc/haskell-hourglass/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
